#ifndef PED_CONSTRAINT_H
#define PED_CONSTRAINT_H

#include "alignment.h"

namespace Ped {

    class Constraint {

        friend class Disk;
        friend class FileSystem;

        private:
        Constraint( );
        Constraint(const PedConstraint *constr);
        Constraint& operator=(const Constraint &constr);

        PedConstraint              *constraint_;
        std::auto_ptr<PedGeometry>  geometry_;
        std::auto_ptr<Geometry>     geom_;

        const PedConstraint*    get_c_constraint    ( ) const;
        PedConstraint*          get_c_constraint    ( );

        public:
        explicit Constraint                         (Alignment& start_align,
                                                     Alignment& end_align,
                                                     Geometry& start_range,
                                                     Geometry& end_range,
                                                     Sector min_size,
                                                     Sector max_size);

        explicit Constraint                         (Geometry& min,
                                                     Geometry& max);

        explicit Constraint                         (Geometry& minmax,
                                                     bool isMin);
        explicit Constraint                         (const Constraint &constr);

        explicit Constraint                         (const Constraint &a,
                                                     const Constraint &b);

        ~Constraint                                 ( );

        Geometry&               solve_max           ( )
            throw (std::runtime_error);
        Geometry&               solve_nearest       (Geometry& geom)
            throw (std::runtime_error);
        bool                    is_solution         (Geometry& geom);

        protected:

    };

};

#endif

/* vim: set tabstop=4 et shiftwidth=4: */
