/*
 *  Copyright (C) 2003 Christian Meyer
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <partedpp/partedpp.h>

using namespace Ped;

/* ------- *
 * private *
 * ------- */

FileSystemType::FileSystemType() {
}

FileSystemType::FileSystemType(const PedFileSystemType *fst)
    : fs_type_(ped_file_system_type_get(fst->name)) {
}

FileSystemType::FileSystemType(const FileSystemType &fst)
    : fs_type_(ped_file_system_type_get(fst.fs_type_->name)) {
}

FileSystemType& FileSystemType::operator=(const FileSystemType &fst) {
    if (this == &fst) {
        return *this;
    }
    fs_type_ = ped_file_system_type_get(fst.fs_type_->name);
    return *this;
}

const PedFileSystemType* FileSystemType::get_c_file_system_type() const {
    return fs_type_;
}

PedFileSystemType* FileSystemType::get_c_file_system_type() {
    return fs_type_;
}

/* ------ *
 * public *
 * ------ */

FileSystemType::FileSystemType(std::string &name)
    : fs_type_(ped_file_system_type_get(name.c_str())) {
}

FileSystemType& FileSystemType::get_next() throw (std::runtime_error) {
    fs_type_ = ped_file_system_type_get_next(fs_type_);
    if (fs_type_) {
        throw std::runtime_error("No further filesystem types found!");
    }
    fstype_ = std::auto_ptr<FileSystemType>(new FileSystemType(fs_type_));
    return *(fstype_.get());
}

const std::string FileSystemType::get_name() const {
    return (std::string(fs_type_->name));
}

FileSystemType::~FileSystemType() {
}

/* vim: set tabstop=4 et shiftwidth=4: */
